@@ -1,3 +1,6 @@
+#![allow(clippy::unknown_clippy_lints)]
+#![allow(clippy::unnecessary_wraps)]
+
 use crate::common::*;
 
 use Function::*;
@@ -27,6 +30,7 @@ lazy_static! {
     ("os", Nullary(os)),
     ("os_family", Nullary(os_family)),
     ("parent_directory", Unary(parent_directory)),
+    ("path_exists", Unary(path_exists)),
     ("quote", Unary(quote)),
     ("replace", Ternary(replace)),
     ("trim", Unary(trim)),
@@ -207,6 +211,10 @@ fn parent_directory(_context: &FunctionContext, path: &str) -> Result<String, St
     .ok_or_else(|| format!("Could not extract parent directory from `{}`", path))
 }
 
+fn path_exists(_context: &FunctionContext, path: &str) -> Result<String, String> {
+  Ok(Utf8Path::new(path).exists().to_string())
+}
+
 fn quote(_context: &FunctionContext, s: &str) -> Result<String, String> {
   Ok(format!("'{}'", s.replace('\'', "'\\''")))
 }
